@@ -37,7 +37,44 @@ class RecordDraftService(RecordService):
         return self.config.draft_cls
 
     # High-level API
-    # Inherits record read, search, create, delete and update
+    # Inherits record read, create, delete and update
+
+    def search(self, identity, params=None, links_config=None, **kwargs):
+        """Search for records matching the querystring."""
+        # Permissions
+        self.require_permission(identity, "search")
+
+        # Merge params
+        # NOTE: We allow using both the params variable, as well as kwargs. The
+        # params is used by the resource, and kwargs is used to have an easier
+        # programatic interface .search(idty, q='...') instead of
+        # .search(idty, params={'q': '...'}).
+        status = kwargs.pop("status", "published")
+        params = params or {}
+        params.update(kwargs)
+
+        # Create a Elasticsearch DSL
+        # Params are returned as [], we give priority to published.
+        _record_cls = self.draft_cls if "draft" == status else self.record_cls
+
+        search = self.search_request(
+            identity, params, _record_cls, preference=False)
+
+        # Run components
+        for component in self.components:
+            if hasattr(component, 'search'):
+                search = component.search(identity, search, params)
+
+        # Execute the search
+        search_result = search.execute()
+
+        return self.result_list(
+            self,
+            identity,
+            search_result,
+            params,
+            links_config=links_config
+        )
 
     def read_draft(self, id_, identity, links_config=None):
         """Retrieve a draft."""
