@@ -7,10 +7,9 @@
 # Invenio-Drafts-Resources is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
 
-docker-services-cli up postgresql es
 python -m check_manifest --ignore ".travis-*" && \
 python -m sphinx.cmd.build -qnNW docs docs/_build/html && \
-docker-services-cli up es postgresql redis
+docker-services-cli up es postgresql
 python -m pytest
 tests_exit_code=$?
 docker-services-cli down
